@@ -59,7 +59,7 @@ use POE::Component::IRC;
 use Data::Dumper;
 use Text::Wrap ();
 
-our $VERSION = 0.65;
+our $VERSION = 0.80;
 
 use base qw( Exporter );
 our @EXPORT  = qw( say emote );
@@ -113,10 +113,6 @@ Runs the bot.  Hands the control over to the POE core.
 sub run {
     my $self = shift;
 
-    # yep, we use irc
-    POE::Component::IRC->new($self->{IRCNAME})
-      or die "Can't instantiate new IRC component!\n";
-
     # create the callbacks to the object states
     POE::Session->create(
         object_states => [
@@ -139,6 +135,7 @@ sub run {
                 irc_kick         => "irc_kicked_state",
                 irc_nick         => "irc_nick_state",
                 irc_mode         => "irc_mode_state",
+                irc_quit         => "irc_quit_state",
 
                 fork_close       => "fork_close_state",
                 fork_error       => "fork_error_state",
@@ -374,6 +371,20 @@ to the server
 
 sub connected { undef }
 
+=head2 userquit( $mess )
+
+$mess looks like
+
+    { who => "nick that quit",
+      body => "quit message",
+    }
+
+=cut
+
+sub userquit {
+    my ($self, $mess) = @_;
+}
+
 
 
 =head1 BOT METHODS
@@ -494,6 +505,9 @@ sub forkit {
         CloseEvent   => "fork_close"
     );
 
+    # Use a signal handler to reap dead processes
+    $poe_kernel->sig_child( $wheel->PID, "got_sigchld" );
+
     # store the wheel object in our bot, so we can retrieve/delete easily
 
     $self->{forks}->{ $wheel->ID } = {
@@ -805,7 +819,7 @@ The name that the bot will identify itself as.  Defaults to
 sub name {
     my $self = shift;
     $self->{name} = shift if @_;
-    $_[0]->{name} or $self->nick . " bot";
+    $self->{name} or $self->nick . " bot";
 }
 
 =head2 channels
@@ -906,10 +920,6 @@ sub start_state {
     # Make an alias for our session, to keep it from getting GC'ed.
     $kernel->alias_set($self->{ALIASNAME});
 
-    # Ask the IRC component to send us all IRC events it receives. This
-    # is the easy, indiscriminate way to do it.
-    $kernel->post($self->{IRCNAME}, 'register', 'all');
-
     $kernel->delay('reconnect', 1 );
 
     $kernel->delay('tick', 30);
@@ -943,7 +953,7 @@ sub reconnect {
 
     $kernel->call( $self->{IRCNAME}, 'disconnect' );
     $kernel->call( $self->{IRCNAME}, 'shutdown' );
-    POE::Component::IRC->new($self->{IRCNAME});
+    POE::Component::IRC->spawn( alias => $self->{IRCNAME} );
     $kernel->post( $self->{IRCNAME}, 'register', 'all' );
 
     $kernel->post($self->{IRCNAME}, 'connect',
@@ -1109,6 +1119,24 @@ sub irc_mode_state {
     }
 }
 
+
+=head2 irc_quit_state
+
+=cut
+
+sub irc_quit_state {
+    my ($self, $kernel, $session) = @_[OBJECT, KERNEL, SESSION];
+    my ($nick, $message) = @_[ARG0..$#_];
+
+    $nick = $self->nick_strip($nick);
+
+    $self->userquit({ who => $nick, body => $message });
+
+    # do this second, so that the userquit implementor has a chance to see
+    # which channels they left
+    $self->_remove_from_all_channels( $nick );
+}
+
 =head2 irc_said_state
 
 Called if we recieve a private or public message.  This
